==> seven_cloudapp_frame-1.0.52.17-py3-none-any.whl: seven_cloudapp_frame/models/db_models/stat/stat_user_log_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2022-08-24 15:02:41
@LastEditTime: 2022-08-24 15:13:08
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class StatUserLogModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(StatUserLogModel, self).__init__(StatUserLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class StatUserLog:

    def __init__(self):
        super(StatUserLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 活动模块标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.key_name = ""  # key名称
        self.key_value = 0  # key值
        self.create_day = 0  # 创建日
        self.create_month = 0  # 创建月
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'key_name', 'key_value', 'create_day', 'create_month', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "stat_user_log_tb"

==> seven_cloudapp_frame-1.1.38.5-py3-none-any.whl: seven_cloudapp_frame/models/db_models/stat/stat_user_log_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2022-08-24 15:02:41
@LastEditTime: 2022-11-24 16:39:38
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class StatUserLogModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(StatUserLogModel, self).__init__(StatUserLog, sub_table)
        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_stat","redis_stat", db_connect_key)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class StatUserLog:

    def __init__(self):
        super(StatUserLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 活动模块标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.key_name = ""  # key名称
        self.key_value = 0  # key值
        self.request_code = ""  # 请求代码
        self.create_day = 0  # 创建日
        self.create_month = 0  # 创建月
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'key_name', 'key_value', 'request_code', 'create_day', 'create_month', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "stat_user_log_tb"
